class aes::opendsa {

  $opendsa_user = opendsa
  $opendsa_group = "${opendsa_user}"
  $opendsa_home = "/srv/${opendsa_user}"
  $opendsa_service = "${opendsa_user}"

  user { "${opendsa_user}" :
    ensure => present,
    home => "${opendsa_home}",
    comment => 'OpenDSA server',
    managehome => false,
    membership => inclusive,
    system => true,
    shell => '/sbin/nologin',
  }

  file { "${opendsa_home}":
    ensure => directory,
    owner  => "${opendsa_user}",
    group  => "${opendsa_group}",
    mode => '0755',
  }

  # This file will be executed as root, which is why we don't let anyone but root examine it.
  file { "${opendsa_home}/on_update.sh":
    ensure => present,
    owner => root,
    group => root,
    mode  => '0700',
    source => "puppet:///modules/${module_name}/opendsa/on_update.sh",
  }

  file { "/etc/systemd/system/${opendsa_service}.service":
    ensure => present,
    owner  => root,
    group  => root,
    mode => '0644',
    source => "puppet:///modules/${module_name}/opendsa/opendsa.service",
  }

  exec { 'update-repo':
    command => "/opt/utils/update_repo.sh ${opendsa_home}/OpenDSA https://oauth2:taNPRZid9Hv6jJtdW_T8@gitlab.liu.se/opendsa/OpenDSA.git exam",
    environment => [ "REPO_USER=${opendsa_user}", "REPO_GROUP=${opendsa_group}", "REPO_ON_UPDATE=${opendsa_home}/on_update.sh" ],
    # This command will need to run "on_update" as root in order to restart the service.
    user => root,
    group => root,
    cwd => "${opendsa_home}",
  }

  file { "${opendsa_home}/manage.sh":
    ensure => present,
    owner  => "${opendsa_user}",
    group  => "${opendsa_group}",
    mode => '0755',
    source => "puppet:///modules/${module_name}/opendsa/manage.sh",
  }

  # Temporary!
  file { '/opt/utils/update_repo.sh':
    ensure  => file,
    mode    => '0755',
    owner   => root,
    group   => root,
    content => file("${module_name}/update_repo.sh"),
  }


 # Do we need port 12000 open? NO
  service { "${opendsa_service}" : 
    ensure => "running",
  }

  # Ändra TDDD86-raden i rules.d/opendsa till "TDDD86[AB]_191219"

}
